@@ -6,13 +6,18 @@
 
 #include "autocorrectionwidget.h"
 #include "autocorrectionutils.h"
+
 #include "ui_autocorrectionwidget.h"
 #include <TextAutoCorrectionCore/ImportAbstractAutocorrection>
 #include <TextAutoCorrectionCore/ImportKMailAutocorrection>
 #include <TextAutoCorrectionCore/ImportLibreOfficeAutocorrection>
 
-#include "selectspecialchardialog.h"
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
 #include <TextAddonsWidgets/LineEditCatchReturnKey>
+#else
+#include <KLineEditEventHandler>
+#endif
+#include <TextAddonsWidgets/SelectSpecialCharDialog>
 
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -59,10 +64,18 @@ AutoCorrectionWidget::AutoCorrectionWidget(QWidget *parent)
     d->ui->add1->setEnabled(false);
     d->ui->add2->setEnabled(false);
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
     TextAddonsWidgets::LineEditCatchReturnKey(d->ui->find, this);
     TextAddonsWidgets::LineEditCatchReturnKey(d->ui->replace, this);
     TextAddonsWidgets::LineEditCatchReturnKey(d->ui->abbreviation, this);
     TextAddonsWidgets::LineEditCatchReturnKey(d->ui->twoUpperLetter, this);
+#else
+    KLineEditEventHandler::catchReturnKey(d->ui->find);
+    KLineEditEventHandler::catchReturnKey(d->ui->replace);
+    KLineEditEventHandler::catchReturnKey(d->ui->abbreviation);
+    KLineEditEventHandler::catchReturnKey(d->ui->twoUpperLetter);
+
+#endif
     connect(d->ui->autoChangeFormat, &QCheckBox::clicked, this, &AutoCorrectionWidget::emitChanged);
     connect(d->ui->autoFormatUrl, &QCheckBox::clicked, this, &AutoCorrectionWidget::emitChanged);
     connect(d->ui->upperCase, &QCheckBox::clicked, this, &AutoCorrectionWidget::emitChanged);
@@ -121,8 +134,14 @@ AutoCorrectionWidget::AutoCorrectionWidget(QWidget *parent)
 
     connect(d->ui->customWritablePath, &QLineEdit::textChanged, this, &AutoCorrectionWidget::emitChanged);
     connect(d->ui->customSystemPath, &QLineEdit::textChanged, this, &AutoCorrectionWidget::emitChanged);
+
+#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
     TextAddonsWidgets::LineEditCatchReturnKey(d->ui->customWritablePath, parent);
     TextAddonsWidgets::LineEditCatchReturnKey(d->ui->customSystemPath, parent);
+#else
+    KLineEditEventHandler::catchReturnKey(d->ui->customWritablePath);
+    KLineEditEventHandler::catchReturnKey(d->ui->customSystemPath);
+#endif
 
     connect(d->ui->customWritablePathToolButton, &QToolButton::clicked, this, [this]() {
         const QString path = QFileDialog::getExistingDirectory(this, i18n("Select Custom Writable Path"));
@@ -331,7 +350,7 @@ void AutoCorrectionWidget::enableDoubleQuotes(bool state)
 
 void AutoCorrectionWidget::selectSingleQuoteCharOpen()
 {
-    QPointer<TextAutoCorrectionWidgets::SelectSpecialCharDialog> dlg = new TextAutoCorrectionWidgets::SelectSpecialCharDialog(this);
+    QPointer<TextAddonsWidgets::SelectSpecialCharDialog> dlg = new TextAddonsWidgets::SelectSpecialCharDialog(this);
     dlg->setCurrentChar(d->m_singleQuotes.begin);
     dlg->showSelectButton(false);
     dlg->autoInsertChar();
@@ -345,7 +364,7 @@ void AutoCorrectionWidget::selectSingleQuoteCharOpen()
 
 void AutoCorrectionWidget::selectSingleQuoteCharClose()
 {
-    QPointer<TextAutoCorrectionWidgets::SelectSpecialCharDialog> dlg = new TextAutoCorrectionWidgets::SelectSpecialCharDialog(this);
+    QPointer<TextAddonsWidgets::SelectSpecialCharDialog> dlg = new TextAddonsWidgets::SelectSpecialCharDialog(this);
     dlg->showSelectButton(false);
     dlg->setCurrentChar(d->m_singleQuotes.end);
     dlg->autoInsertChar();
@@ -367,7 +386,7 @@ void AutoCorrectionWidget::setDefaultSingleQuotes()
 
 void AutoCorrectionWidget::selectDoubleQuoteCharOpen()
 {
-    QPointer<TextAutoCorrectionWidgets::SelectSpecialCharDialog> dlg = new TextAutoCorrectionWidgets::SelectSpecialCharDialog(this);
+    QPointer<TextAddonsWidgets::SelectSpecialCharDialog> dlg = new TextAddonsWidgets::SelectSpecialCharDialog(this);
     dlg->showSelectButton(false);
     dlg->setCurrentChar(d->m_doubleQuotes.begin);
     dlg->autoInsertChar();
@@ -381,7 +400,7 @@ void AutoCorrectionWidget::selectDoubleQuoteCharOpen()
 
 void AutoCorrectionWidget::selectDoubleQuoteCharClose()
 {
-    QPointer<TextAutoCorrectionWidgets::SelectSpecialCharDialog> dlg = new TextAutoCorrectionWidgets::SelectSpecialCharDialog(this);
+    QPointer<TextAddonsWidgets::SelectSpecialCharDialog> dlg = new TextAddonsWidgets::SelectSpecialCharDialog(this);
     dlg->showSelectButton(false);
     dlg->setCurrentChar(d->m_doubleQuotes.end);
     dlg->autoInsertChar();
@@ -717,3 +736,5 @@ void AutoCorrectionWidget::slotExportAutoCorrection()
     }
     d->mAutoCorrection->writeAutoCorrectionXmlFile(saveUrl);
 }
+
+#include "moc_autocorrectionwidget.cpp"
