@@ -5,7 +5,6 @@
 */
 
 #include "texttospeechcontainergui.h"
-#include "texttospeech.h"
 #include "texttospeechcontainerwidget.h"
 #include <KLocalizedString>
 #include <QAction>
@@ -70,3 +69,5 @@ int main(int argc, char **argv)
     delete w;
     return 0;
 }
+
+#include "moc_texttospeechcontainergui.cpp"
