@@ -13,6 +13,10 @@
 namespace TextEmoticonsCore
 {
 class CustomEmojiIconManager;
+/**
+ * @brief The EmojiModel class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class TEXTEMOTICONSCORE_EXPORT EmojiModel : public QAbstractListModel
 {
     Q_OBJECT
@@ -42,6 +46,8 @@ public:
     Q_REQUIRED_RESULT TextEmoticonsCore::CustomEmojiIconManager *customEmojiIconManager() const;
     void setCustomEmojiIconManager(TextEmoticonsCore::CustomEmojiIconManager *newCustomEmojiIconManager);
 
+    void setExcludeEmoticons(const QStringList &emoticons);
+
 private:
     Q_DISABLE_COPY(EmojiModel)
     QList<TextEmoticonsCore::UnicodeEmoticon> mEmoticonList;
