@@ -26,19 +26,20 @@ public:
     }
     void loadRecentUsed()
     {
-        KConfigGroup group(KSharedConfig::openConfig(), myEmoticonRecentUsedGroupName);
+        KConfigGroup group(KSharedConfig::openConfig(), QLatin1String(myEmoticonRecentUsedGroupName));
         mRecentIdentifier = group.readEntry("Recents", QStringList());
     }
 
     void writeRecentUsed()
     {
-        KConfigGroup group(KSharedConfig::openConfig(), myEmoticonRecentUsedGroupName);
+        KConfigGroup group(KSharedConfig::openConfig(), QLatin1String(myEmoticonRecentUsedGroupName));
         group.writeEntry("Recents", mRecentIdentifier);
         group.sync();
     }
 
     TextEmoticonsCore::EmojiModel *const mEmojiModel;
     QStringList mRecentIdentifier;
+    QStringList mExcludeEmoticons;
 };
 
 EmojiModelManager::EmojiModelManager(QObject *parent)
@@ -99,4 +100,18 @@ void EmojiModelManager::setCustomEmojiIconManager(CustomEmojiIconManager *newCus
     d->mEmojiModel->setCustomEmojiIconManager(newCustomEmojiIconManager);
 }
 
+QStringList EmojiModelManager::excludeEmoticons() const
+{
+    return d->mExcludeEmoticons;
+}
+
+void EmojiModelManager::setExcludeEmoticons(const QStringList &emoticons)
+{
+    if (d->mExcludeEmoticons != emoticons) {
+        d->mExcludeEmoticons = emoticons;
+        d->mEmojiModel->setExcludeEmoticons(d->mExcludeEmoticons);
+        Q_EMIT excludeEmoticonsChanged();
+    }
+}
+
 #include "moc_emojimodelmanager.cpp"
