@@ -7,10 +7,15 @@
 
 #include "textemoticonscore_export.h"
 #include <QObject>
+#include <memory>
 namespace TextEmoticonsCore
 {
 class EmojiModel;
 class CustomEmojiIconManager;
+/**
+ * @brief The EmojiModelManager class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class TEXTEMOTICONSCORE_EXPORT EmojiModelManager : public QObject
 {
     Q_OBJECT
@@ -28,13 +33,15 @@ public:
     Q_REQUIRED_RESULT TextEmoticonsCore::CustomEmojiIconManager *customEmojiIconManager() const;
     void setCustomEmojiIconManager(TextEmoticonsCore::CustomEmojiIconManager *newCustomEmojiIconManager);
 
+    [[nodiscard]] QStringList excludeEmoticons() const;
+    void setExcludeEmoticons(const QStringList &emoticons);
+
 Q_SIGNALS:
     void usedIdentifierChanged(const QStringList &lst);
+    void excludeEmoticonsChanged();
 
 private:
-    TextEmoticonsCore::EmojiModel *const mEmojiModel;
-    QStringList mRecentIdentifier;
-    void loadRecentUsed();
-    void writeRecentUsed();
+    class EmojiModelManagerPrivate;
+    std::unique_ptr<EmojiModelManagerPrivate> const d;
 };
 }
