@@ -31,12 +31,22 @@ TextTranslator::TranslatorEnginePlugin *BingEngineClient::createTranslator()
     return new BingEnginePlugin();
 }
 
-QMap<TextTranslator::TranslatorUtil::Language, QString> BingEngineClient::supportedLanguages()
+QMap<TextTranslator::TranslatorUtil::Language, QString> BingEngineClient::supportedFromLanguages()
 {
-    if (mLanguages.isEmpty()) {
-        mLanguages = fillLanguages();
+    if (mFromLanguages.isEmpty()) {
+        mFromLanguages = fillLanguages();
     }
-    return mLanguages;
+    return mFromLanguages;
+}
+
+QMap<TextTranslator::TranslatorUtil::Language, QString> BingEngineClient::supportedToLanguages()
+{
+    return supportedFromLanguages();
+}
+
+TextTranslator::TranslatorEngineClient::EngineType BingEngineClient::engineType() const
+{
+    return TextTranslator::TranslatorEngineClient::Network;
 }
 
 bool BingEngineClient::isSupported(TextTranslator::TranslatorUtil::Language lang) const
