@@ -15,16 +15,34 @@ TranslatorEngineClient::TranslatorEngineClient(QObject *parent)
 
 TranslatorEngineClient::~TranslatorEngineClient() = default;
 
+void TranslatorEngineClient::updateListLanguages()
+{
+    // Nothing by default
+}
+
 bool TranslatorEngineClient::hasConfigurationDialog() const
 {
     // False by default
     return false;
 }
 
-void TranslatorEngineClient::showConfigureDialog(QWidget *parentWidget)
+bool TranslatorEngineClient::showConfigureDialog(QWidget *parentWidget)
 {
     Q_UNUSED(parentWidget);
     // Nothing by default
+    return false;
+}
+
+void TranslatorEngineClient::generateToListFromCurrentToLanguage(const QString &languageCode)
+{
+    Q_UNUSED(languageCode);
+    // Nothing by default
+}
+
+bool TranslatorEngineClient::hasInvertSupport() const
+{
+    // True by default
+    return true;
 }
 
 QMap<TextTranslator::TranslatorUtil::Language, QString> TranslatorEngineClient::fillLanguages()
